@@ -274,7 +274,7 @@ fn rvalue(i: &str) -> IResult<&str, RValue> {
         ($name:ident, $operand: ident, $operator: expr) => {
             fn $name(i: &str) -> IResult<&str, RValue> {
                 let (i, init) = $operand(i)?;
-                fold_many0(pair($operator, $operand), init, |left, (op, right)| {
+                fold_many0(pair($operator, $operand), move || init.clone(), |left, (op, right)| {
                     RValue::Binary(Box::new(left), op.to_string(), Box::new(right))
                 })(i)
             }
